# juntagrico_assignment_request

[![Build Status](https://travis-ci.com/juntagrico/juntagrico-assignment-request.svg?branch=master)](https://travis-ci.com/juntagrico/juntagrico-assignment-request)
[![Maintainability](https://api.codeclimate.com/v1/badges/6c1a453b157b9395a858/maintainability)](https://codeclimate.com/github/juntagrico/juntagrico-assignment-request/maintainability)
[![Test Coverage](https://api.codeclimate.com/v1/badges/6c1a453b157b9395a858/test_coverage)](https://codeclimate.com/github/juntagrico/juntagrico-assignment-request/test_coverage)

This is an extension for juntagrico. You can find more information about juntagrico here
(https://github.com/juntagrico/juntagrico)

For more information information about how to install this app hop over to the doc section of the repo.